@@ -28,7 +28,6 @@
 #include <QPainter>
 #include <QStack>
 #include <QUrl>
-#include <QXmlSimpleReader>
 
 #include <KActionMenu>
 #include <KDesktopFile>
@@ -37,6 +36,7 @@
 #include <KMessageBox>
 
 #include <QtDebug>
+#include <kwidgetsaddons_version.h>
 
 Phrase::Phrase()
 {
@@ -296,13 +296,25 @@ int PhraseBook::save(QWidget *parent, const QString &title, QUrl &url, bool phra
         if (url.fileName(QUrl::PrettyDecoded).contains(QLatin1Char('.')) == 0) {
             url = url.adjusted(QUrl::RemoveFilename);
             url.setPath(url.path() + url.fileName(QUrl::PrettyDecoded) + QStringLiteral(".phrasebook"));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         } else if (url.fileName(QUrl::PrettyDecoded).rightRef(11).contains(QLatin1String(".phrasebook"), Qt::CaseInsensitive) == 0) {
+#else
+        } else if (url.fileName(QUrl::PrettyDecoded).right(11).contains(QLatin1String(".phrasebook"), Qt::CaseInsensitive) == 0) {
+#endif
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            int filetype = KMessageBox::questionTwoActionsCancel(nullptr, QStringLiteral("<qt>%1</qt>").arg(i18n("Your chosen filename <i>%1</i> has a different extension than <i>.phrasebook</i>. "
+#else
             int filetype = KMessageBox::questionYesNoCancel(nullptr, QStringLiteral("<qt>%1</qt>").arg(i18n("Your chosen filename <i>%1</i> has a different extension than <i>.phrasebook</i>. "
+#endif
                            "Do you wish to add <i>.phrasebook</i> to the filename?", url.fileName())), i18n("File Extension"), KGuiItem(i18n("Add")), KGuiItem(i18n("Do Not Add")));
             if (filetype == KMessageBox::Cancel) {
                 return 0;
             }
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (filetype == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             if (filetype == KMessageBox::Yes) {
+#endif
                 url = url.adjusted(QUrl::RemoveFilename);
                 url.setPath(url.path() + url.fileName(QUrl::PrettyDecoded) + QStringLiteral(".phrasebook"));
             }
@@ -312,12 +324,20 @@ int PhraseBook::save(QWidget *parent, const QString &title, QUrl &url, bool phra
         if (url.fileName(QUrl::PrettyDecoded).rightRef(11).contains(QLatin1String(".phrasebook"), Qt::CaseInsensitive) == 0) {
             result = save(url, false);
         } else {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            int filetype = KMessageBox::questionTwoActionsCancel(nullptr, QStringLiteral("<qt>%1</qt>").arg(i18n("Your chosen filename <i>%1</i> has the extension <i>.phrasebook</i>. "
+#else
             int filetype = KMessageBox::questionYesNoCancel(nullptr, QStringLiteral("<qt>%1</qt>").arg(i18n("Your chosen filename <i>%1</i> has the extension <i>.phrasebook</i>. "
+#endif
                            "Do you wish to save in phrasebook format?", url.fileName())), i18n("File Extension"), KGuiItem(i18n("As Phrasebook")), KGuiItem(i18n("As Plain Text")));
             if (filetype == KMessageBox::Cancel) {
                 return 0;
             }
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (filetype == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             if (filetype == KMessageBox::Yes) {
+#endif
                 result = save(url, true);
             } else {
                 result = save(url, false);
