@@ -36,6 +36,7 @@
 #include "phrasebook.h"
 
 #include <QDebug>
+#include <kwidgetsaddons_version.h>
 
 const int kTextColumn = 0;
 const int kShortcutColumn = 1;
@@ -93,7 +94,7 @@ PhraseBookDialog::PhraseBookDialog()
     initGUI();
     initActions();
     initStandardPhraseBooks();
-    QString standardBook = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("standard.phrasebook"));
+    QString standardBook = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("standard.phrasebook"));
     if (!standardBook.isNull() && !standardBook.isEmpty()) {
         QFile file(standardBook);
         file.open(QIODevice::ReadOnly);
@@ -421,16 +422,28 @@ void PhraseBookDialog::selectionChanged()
 bool PhraseBookDialog::queryClose()
 {
     if (phrasebookChanged) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        int answer = KMessageBox::questionTwoActionsCancel(this,
+#else
         int answer = KMessageBox::questionYesNoCancel(this,
+#endif
                      i18n("<qt>There are unsaved changes.<br />Do you want to apply the changes before closing the \"phrase book\" window or discard the changes?</qt>"),
                      i18n("Closing \"Phrase Book\" Window"),
                      KStandardGuiItem::apply(), KStandardGuiItem::discard(),
                      KStandardGuiItem::cancel(), QStringLiteral("AutomaticSave"));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+#else
         if (answer == KMessageBox::Yes) {
+#endif
             slotSave();
             return true;
         }
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        return (answer == KMessageBox::ButtonCode::SecondaryAction);
+#else
         return (answer == KMessageBox::No);
+#endif
     }
     return true;
 }
@@ -486,7 +499,7 @@ void PhraseBookDialog::setShortcut(const QKeySequence& sequence)
 //         QString s = i18n("In order to use the '%1' key as a shortcut, "
 //                          "it must be combined with the "
 //                          "Win, Alt, Ctrl, and/or Shift keys.", QChar(key.sym()));
-//         KMessageBox::sorry( this, s, i18n("Invalid Shortcut Key") );
+//         KMessageBox::error( this, s, i18n("Invalid Shortcut Key") );
 //         return;
 //      }
 //#endif
@@ -616,7 +629,7 @@ void PhraseBookDialog::slotAddPhrase()
 
 void PhraseBookDialog::slotSave()
 {
-    QString standardBook = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("standard.phrasebook"));
+    QString standardBook = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("standard.phrasebook"));
     if (!standardBook.isNull() && !standardBook.isEmpty()) {
         QFile file(standardBook);
         file.open(QIODevice::WriteOnly);
@@ -662,7 +675,7 @@ void PhraseBookDialog::slotImportPhrasebook(const QUrl &url)
             focusNewItem(parentIndex, item);
         } else {
             qDebug() << "Unable to open file " << url.toLocalFile();
-            KMessageBox::sorry(this, i18n("There was an error loading file\n%1", url.toLocalFile()));
+            KMessageBox::error(this, i18n("There was an error loading file\n%1", url.toLocalFile()));
         }
     }
 }
@@ -680,7 +693,7 @@ void PhraseBookDialog::slotExportPhrasebook()
         out << content;
         file.close();
     } else {
-        KMessageBox::sorry(this, i18n("There was an error saving file\n%1", url.toLocalFile()));
+        KMessageBox::error(this, i18n("There was an error saving file\n%1", url.toLocalFile()));
     }
 }
 
